==> dif-document-repository-db-2.4.3-8-20191210.132250-1-sources.jar: pt/digitalis/dif/documents/repository/DocumentRepositoryConfiguration.java <==
package pt.digitalis.dif.documents.repository;

import pt.digitalis.dif.ioc.DIFIoCRegistry;
import pt.digitalis.utils.config.ConfigurationException;
import pt.digitalis.utils.config.IConfigurations;
import pt.digitalis.utils.config.annotations.ConfigDefault;
import pt.digitalis.utils.config.annotations.ConfigID;
import pt.digitalis.utils.config.annotations.ConfigIgnore;
import pt.digitalis.utils.config.annotations.ConfigSectionID;
import pt.digitalis.utils.config.annotations.ConfigVirtualPathForNode;

/**
 * @author Galaio da Silva <a href="mailto:jgalaio@digitalis.pt">jgalaio@digitalis.pt</a><br/>
 * @created Jun 22, 2009
 */
@ConfigID("DocumentRepository")
@ConfigSectionID("Repository")
@ConfigVirtualPathForNode("dif2/Document Repository")
public class DocumentRepositoryConfiguration {

    /**
     * LuceneConfigurations instance.
     */
    private static DocumentRepositoryConfiguration configuration;

    /**
     * Get the <code>LuceneConfiguration</code>.
     *
     * @return the LuceneConfiguration instance.
     * @throws ConfigurationException
     */
    @ConfigIgnore
    public static DocumentRepositoryConfiguration getInstance() throws ConfigurationException
    {

        if (configuration == null)
        {
            configuration = DIFIoCRegistry.getRegistry().getImplementation(IConfigurations.class)
                    .readConfiguration(DocumentRepositoryConfiguration.class);
        }
        return configuration;
    }

    /** the maximum Document size */
    private Integer maxDocumentSize;

    /**
     * Inspector for the 'maxDocumentSize' attribute.
     *
     * @return the maxDocumentSize value
     */
    @ConfigDefault("1024")
    public Integer getMaxDocumentSize()
    {
        return maxDocumentSize;
    }

    /**
     * Modifier for the 'maxDocumentSize' attribute.
     *
     * @param maxDocumentSize
     *            the new maxDocumentSize value to set
     */
    public void setMaxDocumentSize(String maxDocumentSize)
    {
        if (maxDocumentSize != null && !"".equals(maxDocumentSize))
        {
            this.maxDocumentSize = new Integer(maxDocumentSize);
        }
    }
}

==> dif-document-repository-db-2.6.1-8-20200421.173538-1-sources.jar: pt/digitalis/dif/documents/repository/DocumentRepositoryConfiguration.java <==
package pt.digitalis.dif.documents.repository;

import pt.digitalis.dif.ioc.DIFIoCRegistry;
import pt.digitalis.utils.config.ConfigurationException;
import pt.digitalis.utils.config.IConfigurations;
import pt.digitalis.utils.config.annotations.ConfigDefault;
import pt.digitalis.utils.config.annotations.ConfigID;
import pt.digitalis.utils.config.annotations.ConfigIgnore;
import pt.digitalis.utils.config.annotations.ConfigSectionID;
import pt.digitalis.utils.config.annotations.ConfigVirtualPathForNode;

/**
 * @author Galaio da Silva <a href="mailto:jgalaio@digitalis.pt">jgalaio@digitalis.pt</a><br/>
 * @created Jun 22, 2009
 */
@ConfigID("DocumentRepository")
@ConfigSectionID("Repository")
@ConfigVirtualPathForNode("dif2/Document Repository")
public class DocumentRepositoryConfiguration
{

    /**
     * LuceneConfigurations instance.
     */
    private static DocumentRepositoryConfiguration configuration;

    /** the maximum Document size */
    private Integer maxDocumentSize;

    /**
     * Get the <code>LuceneConfiguration</code>.
     *
     * @return the LuceneConfiguration instance.
     *
     * @exception ConfigurationException
     */
    @ConfigIgnore
    public static DocumentRepositoryConfiguration getInstance() throws ConfigurationException
    {

        if (configuration == null)
        {
            configuration = DIFIoCRegistry.getRegistry().getImplementation(IConfigurations.class)
                    .readConfiguration(DocumentRepositoryConfiguration.class);
        }
        return configuration;
    }

    /**
     * Inspector for the 'maxDocumentSize' attribute.
     *
     * @return the maxDocumentSize value
     */
    @ConfigDefault("1024")
    public Integer getMaxDocumentSize()
    {
        return maxDocumentSize;
    }

    /**
     * Modifier for the 'maxDocumentSize' attribute.
     *
     * @param maxDocumentSize the new maxDocumentSize value to set
     */
    public void setMaxDocumentSize(String maxDocumentSize)
    {
        if (maxDocumentSize != null && !"".equals(maxDocumentSize))
        {
            this.maxDocumentSize = new Integer(maxDocumentSize);
        }
    }
}
